@@ -24,8 +24,8 @@ void foreach(std::vector<T>& v, Functor& func, bool verbose=false){
   std::cout << "\r" << std::endl;
 }
 
-int ipow(int base, int exp){
-  int result = 1;
+long ipow(int base, int exp){
+  long result = 1;
   for (;;){
     if (exp & 1)
       result *= base;
