@@ -1,4 +1,7 @@
 
+//libs - must be the first of all
+#include "libs/json.hpp"
+
 //common
 #include "common/utils.cc"
 #include "common/exceptions.cc"
@@ -9,7 +12,6 @@
 
 //binarization
 #include "binarization/kernelcanvas.cc"
-#include "binarization/averageentry.cc"
 
 //wisard model
 #include "models/wisard/ram.cc"
@@ -19,3 +21,7 @@
 //cluswisard wisard_model
 #include "models/cluswisard/cluster.cc"
 #include "models/cluswisard/cluswisard.cc"
+
+//regression wisard model
+#include "models/regressionwisard/regressionram.cc"
+#include "models/regressionwisard/regressionwisard.cc"
